#define XERR "sourcescript"
#include "sourcescript.ih"

    // by handler/sourcescript.cc

SourceScript::SourceScript(OptBase &optBase)
:
    d_stBase(dynamic_cast<STBase &>(optBase))
{}
